@@ -1,7 +1,7 @@
 const char *authors =
 "Maintainers\n"
 "-------\n"
-"Fredrik Arnerup		<e97_far@e.kth.se>\n"
+"Fredrik Arnerup		<arnerup@kth.se>\n"
 "Rasmus Kaj		<kaj@e.kth.se>\n"
 "\n"
 "Contributors\n"
