@@ -1,5 +1,5 @@
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "docmeta.h"
 #include "sigc++/sigc++.h"
@@ -19,7 +19,7 @@ DocMeta::DocMeta(DocRef _document, const Glib::ustring &filename)
 //   document = orig.document;
 // }
 
-SigC::Signal0<void>& DocMeta::changed_signal() {
+sigc::signal<void>& DocMeta::changed_signal() {
   return data->changed_signal;
 }
 
