@@ -18,7 +18,7 @@ public:
   Document* operator->() const { return document.operator->(); }
 
   /** Returns a signal that is emitted when the data has changed. */
-  SigC::Signal0<void>& changed_signal();
+  sigc::signal<void>& changed_signal();
 
   const Glib::ustring& get_filename() const { return data->filename; }
   void set_filename(const Glib::ustring &filename);
@@ -28,7 +28,7 @@ public:
 private:
   class DocData: public RefCounted {
   public:
-    SigC::Signal0<void> changed_signal;
+    sigc::signal<void> changed_signal;
     Glib::ustring filename;
   };
   Glib::RefPtr<DocData> data;
