@@ -9,7 +9,7 @@
 #include <gtkmm/separator.h>
 #include <gtkmm/radiobutton.h>
 #include <gtkmm/checkbutton.h>
-#include <gtkmm/combo.h>
+#include <gtkmm/comboboxtext.h>
 #include <gtkmm/stock.h>
 #include <gtkmm/image.h>
 
@@ -44,7 +44,7 @@ DocPropsDialog::DocPropsDialog():
   single_sided_button = manage(new Gtk::RadioButton("_Single-sided", true));
   double_sided_button = manage(new Gtk::RadioButton("_Double-sided", true));
 
-  paper_size = manage(new Gtk::Combo());
+  paper_size = manage(new Gtk::ComboBoxText());
   file_entry = manage(new FileEntry("Select template"));
   first_page = manage(new Spinner(config.StartPage.values.front(), false));
 
@@ -59,27 +59,6 @@ DocPropsDialog::DocPropsDialog():
   set_modal(true);
   set_resizable(false);
 
-  {
-    std::string& default_paper = config.PaperName.values.front();
-    bool default_is_known = false;
-    std::list<std::string> paper_list;
-    for(std::map<std::string, Papers::Size>::const_iterator 
-	  i = papers.sizes.begin(); i!=papers.sizes.end(); i++) {
-      paper_list.push_back(i->first);
-      if(i->first == default_paper)
-	default_is_known = true;
-    }
-    paper_size->set_popdown_strings(paper_list);
-    if(!default_is_known) {
-      warning << "Paper type \"" << default_paper 
-	      << "\" is unknown." << std::endl;
-      default_paper = "A4";
-      config.PaperName.values.clear();
-      config.PaperName.values.push_back(default_paper);
-    }
-    paper_size->get_entry()->set_text(default_paper);
-  }
-
   {
     Gtk::RadioButton::Group group = landscape_button->get_group();
     portrait_button->set_group(group);
@@ -103,7 +82,7 @@ DocPropsDialog::DocPropsDialog():
   Gtk::Label *format_label = 
     manage(new Gtk::Label("<b>Document _format</b>", 0.0, 0.5, true));
   format_label->set_use_markup();
-  format_label->set_mnemonic_widget(*paper_size->get_entry());
+  format_label->set_mnemonic_widget(*paper_size);
   format_box->pack_start(*format_label);
   Gtk::HBox *format_box2 = manage(new Gtk::HBox());
   format_box2->pack_start(*manage(new Gtk::Label("  ")));
@@ -135,14 +114,12 @@ DocPropsDialog::DocPropsDialog():
     single_sided_button->set_active() :
     double_sided_button->set_active();
 
-  paper_size->get_entry()->set_editable(false);
-
   cancel_button = add_button(Gtk::Stock::CANCEL, 0);
   ok_button = add_button(Gtk::Stock::OK, 1);
   create_button = add_button(Gtk::Stock::NEW, 1);
 
   template_button->signal_clicked().connect
-    (slot(*this, &DocPropsDialog::update_mode));
+    (sigc::mem_fun(*this, &DocPropsDialog::update_mode));
   update_mode();
 
   get_vbox()->show_all();
@@ -157,7 +134,29 @@ void DocPropsDialog::update_mode() {
   file_entry->set_sensitive(active);
 }
 
+namespace {
+  // build list of paper sizes
+  void fill_paper_size(Gtk::ComboBoxText &paper_size,
+                       std::string selected_paper) {
+    if(papers.sizes.find(selected_paper) == papers.sizes.end()) {
+      warning << "Paper format \"" << selected_paper 
+	      << "\" is unknown." << std::endl;
+      selected_paper = "A4";
+    }
+    int i = 0;
+    for(std::map<std::string, Papers::Size>::const_iterator
+	  size = papers.sizes.begin();
+        size != papers.sizes.end();
+        size++, i++) {
+      paper_size.append_text(size->first);
+      if(size->first == selected_paper)
+        paper_size.set_active(i);
+    }
+  }
+}
+
 void DocPropsDialog::show_it(DocumentView *_view, bool create_new) {
+  std::string selected_paper = config.PaperName.values.front();
   new_document = create_new;
   view = _view;
   if(!new_document) {
@@ -170,7 +169,7 @@ void DocPropsDialog::show_it(DocumentView *_view, bool create_new) {
     portrait_button->set_active(document->get_orientation()
 				== Papers::PORTRAIT);
     double_sided_button->set_active(document->is_doublesided());
-    paper_size->get_entry()->set_text(document->get_paper_name());
+    selected_paper = document->get_paper_name();
 
     create_button->hide(); ok_button->show();
     cancel_button->grab_default();
@@ -186,6 +185,9 @@ void DocPropsDialog::show_it(DocumentView *_view, bool create_new) {
     show();
   }
 
+  Glib::RefPtr<Gtk::ListStore>::cast_dynamic(paper_size->get_model())->clear();
+  fill_paper_size(*paper_size, selected_paper);
+
   // have to show() first
   set_title(new_document
 	    ? "Create new document"
@@ -217,8 +219,8 @@ void DocPropsDialog::on_response(int response_id) {
 	config.DocTemplatePath.values.front() = file_entry->entry.get_text();
       } else {
 	document = Document::create();
-	document->set_paper_name(paper_size->get_entry()->get_text());
-	config.PaperName.values.front() = paper_size->get_entry()->get_text();
+	document->set_paper_name(paper_size->get_active_text());
+	config.PaperName.values.front() = paper_size->get_active_text();
 	document->set_orientation(orientation);
 	config.Landscape.values.front() = !portrait_button->get_active();
 	document->set_doublesided(double_sided_button->get_active());
@@ -243,8 +245,8 @@ void DocPropsDialog::on_response(int response_id) {
 	  config.DocTemplatePath.values.front() = file_entry->entry.get_text();
 	} else {
 	  document->set_template("");
-	  document->set_paper_name(paper_size->get_entry()->get_text());
-	  config.PaperName.values.front()= paper_size->get_entry()->get_text();
+	  document->set_paper_name(paper_size->get_active_text());
+	  config.PaperName.values.front()= paper_size->get_active_text();
 	  document->set_orientation(orientation);
 	  config.Landscape.values.front() = !portrait_button->get_active();
 	  document->set_doublesided(double_sided_button->get_active());
