@@ -1,7 +1,7 @@
 #ifndef DOCPROPSDIALOG_H	// -*- c++ -*-
 #define DOCPROPSDIALOG_H
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "widget/dialogwrap.h"
 
@@ -11,7 +11,7 @@ namespace Gtk {
   class RadioButton;
   class Button;
   class VBox;
-  class Combo;
+  class ComboBoxText;
 };
 class FileEntry;
 class Spinner;
@@ -32,7 +32,7 @@ private:
   Gtk::CheckButton *template_button;
   Gtk::Button *cancel_button, *ok_button, *create_button;
   Gtk::VBox *format_box;
-  Gtk::Combo *paper_size;
+  Gtk::ComboBoxText *paper_size;
   FileEntry *file_entry;
   Spinner *first_page;
   bool new_document;
