@@ -24,10 +24,9 @@
 #include "ps/type42.h"
 #include "ps/pdf.h"
 
-SigC::Signal1<void, DocRef> Document::changed_signal;
-SigC::Signal1<void, DocRef> Document::size_changed_signal;
-SigC::Signal1<void, DocRef> Document::selection_changed_signal;
-SigC::Signal1<void, DocRef> Document::streams_changed_signal;
+sigc::signal<void, DocRef> Document::changed_signal;
+sigc::signal<void, DocRef> Document::selection_changed_signal;
+sigc::signal<void, DocRef> Document::streams_changed_signal;
 
 namespace {			// local
   class NameOrder {
@@ -504,7 +503,7 @@ void Document::set_first_page_num(int num) {
 void Document::set_orientation(Papers::Orientation _orientation) {
   orientation = _orientation;
   changed_signal(self());
-  size_changed_signal(self());
+  size_changed_signal();
 }
 
 void Document::set_paper_name(const std::string &_paper_name) {
@@ -512,7 +511,7 @@ void Document::set_paper_name(const std::string &_paper_name) {
     throw Error::PaperName(_paper_name);
   paper_name = _paper_name;
   changed_signal(self());
-  size_changed_signal(self());
+  size_changed_signal();
 }
 
 xmlpp::Document *Document::xml_save(const FileContext &context) {
