@@ -205,7 +205,7 @@ void Group::group_selected() {
     warning << "Got a strange group. Deleting it again." << std::endl;
     delete group;
   }
-  group_changed_signal(this);
+  group_changed_signal();
 }
 
 void Group::ungroup_selected() {
@@ -231,7 +231,7 @@ void Group::ungroup_selected() {
 	if(!ungroup(group))
 	  warning << "Group not in this group" << std::endl;
 	delete group;
-	group_changed_signal(this);
+	group_changed_signal();
       }
     }
 }
@@ -244,7 +244,7 @@ void Group::add(Pagent* obj) {
   // the front is the top
   childs.push_front(obj);
   obj->set_parent(this);
-  group_changed_signal(this);
+  group_changed_signal();
 }
 
 Pagent* Group::ungroup(Pagent* obj) {
@@ -253,7 +253,7 @@ Pagent* Group::ungroup(Pagent* obj) {
     return 0;
   childs.erase(i);
   obj->set_parent(parent);
-  group_changed_signal(this);
+  group_changed_signal();
   return obj;
 }
 
@@ -299,16 +299,16 @@ void Group::rearrange_selected(RearrangeTarget target) {
       }
     }
   }
-  group_changed_signal(this);
-  geometry_changed_signal(this);
+  group_changed_signal();
+  geometry_changed_signal();
 }
 
-void Group::child_props_changed(Pagent *pagent) {
+void Group::child_props_changed() {
   //  if(pagent!=this) // no infinite loops, please
-  props_changed_signal(this);
+  props_changed_signal();
 }
 
-void Group::child_geometry_changed(Pagent *pagent) {
+void Group::child_geometry_changed() {
   //  if(pagent!=this) // no infinite loops, please
-  geometry_changed_signal(this);
+  geometry_changed_signal();
 }
