@@ -30,7 +30,7 @@ public:
   void set_flow_around(bool);
   bool get_flow_around() const;
   Boundary get_obstacle_boundary() const;
-  BoundaryVect Group::obstacle_list() const;
+  BoundaryVect obstacle_list() const;
   
   void add(Pagent* obj);
   Pagent* ungroup(Pagent* obj);
@@ -49,13 +49,13 @@ public:
   ChildVec::const_reverse_iterator prend() const { return childs.rend(); }
 
   // A change in a child is a change in the group:
-  virtual void child_props_changed(Pagent *pagent);
-  virtual void child_geometry_changed(Pagent *pagent);
+  virtual void child_props_changed();
+  virtual void child_geometry_changed();
   
   /** Raised on direct changes to the group (i.e. new / ungrouped member) */
-  SigC::Signal1<void, Pagent*> group_changed_signal; 
+  sigc::signal<void> group_changed_signal; 
 private:
-  Boundary Group::get_untransformed_box() const;
+  Boundary get_untransformed_box() const;
   
   ChildVec childs;
 };
