@@ -20,8 +20,10 @@ public:
   virtual xmlpp::Element *save(xmlpp::Element& parent_node,
 			       const FileContext &context) const ;
   virtual void print(std::ostream &out, bool grayscale = false) const;
+  virtual void print_pdf(PDF::Content::Ptr pdf) const;
 
-
+  void generate_picture(std::ostream& psstream) const;
+  
   // *** undoable actions ***
   void set_association(const std::string &s);
 
@@ -29,17 +31,16 @@ public:
   // *** probe state ***
   Boundary get_box() const;
   const std::string &get_association() const {return association;}
-  Vector get_inherent_size() const { return Vector(width, height); }
+  Vector get_inherent_size() const { return inherentsize; }
   
 protected:
-  std::string association, parsed_file;
+  std::string association;
   FileWatcher filewatcher;
 
-  void generate_picture(FileCallback callback);
   void on_file_modified();
   void read_size();
 private:
-  float width, height;
+  Vector lowerleft, inherentsize;
 };
 
 #endif
