@@ -19,7 +19,7 @@ Pagent::Pagent(Group *_parent, const std::string& _name)
   obstacle_margin(0)
 {
   // a geometry change implies a properties change
-  geometry_changed_signal.connect(props_changed_signal.slot());
+  geometry_changed_signal.connect(props_changed_signal.make_slot());
   // a geometry change does NOT imply a redraw
 
   connect_to_parent();
@@ -33,6 +33,11 @@ void Pagent::set_translation(const Vector& v) {
   set_matrix(m);
 }
 
+void Pagent::set_shearing(float shear) {
+  Matrix m = get_matrix(); m.set_sh(shear);
+  set_matrix(m);
+}
+
 void Pagent::set_rotation(float angle) {
   Matrix m = get_matrix(); m.set_rot(angle);
   set_matrix(m);
@@ -46,28 +51,28 @@ void Pagent::set_scaling(float xfactor, float yfactor) {
 void Pagent::set_lock(bool _locked) {
   if(_locked != locked) {
     locked = _locked;
-    props_changed_signal(this);
+    props_changed_signal();
   }
 }
 
 void Pagent::set_flow_around(bool _flow_around) {
   if(flow_around != _flow_around) {
     flow_around = _flow_around;
-    props_changed_signal(this);
+    props_changed_signal();
   }
 }
 
 void Pagent::set_obstacle_margin(float margin) {
   if(margin != obstacle_margin) {
     obstacle_margin = margin;
-    props_changed_signal(this);
+    props_changed_signal();
   }
 }
 
 void Pagent::set_name(const std::string &_name) {
   if(_name != name) {
     name = _name;
-    props_changed_signal(this);
+    props_changed_signal();
   }
 }
 
@@ -86,7 +91,6 @@ void Pagent::set_parent(Group *_parent) {
   }
   parent = _parent;
   connect_to_parent();
-  props_changed_signal(this);
 }
 
 void Pagent::set_matrix(Matrix m) {
@@ -96,7 +100,7 @@ void Pagent::set_matrix(Matrix m) {
   if(m.sc_x() == 0 || m.sc_y() == 0 || m.det() == 0)
     throw std::runtime_error("Bad matrix in set_matrix: " + tostr(m));
   matrix = m;
-  geometry_changed_signal(this);
+  geometry_changed_signal();
 }
 
 Group& Pagent::get_parent() {
@@ -119,13 +123,12 @@ void Pagent::connect_to_parent() {
   // a group would need to maintain a list of connections.
   // Note: we will get multible implicit signals.
   if(parent) {
-    using SigC::slot;
-      geometry_connection = geometry_changed_signal.connect
-	(slot(*parent, &Group::child_geometry_changed));
-
-      props_connection = props_changed_signal.connect
-	(slot(*parent, &Group::child_props_changed));
-    }
+    geometry_connection = geometry_changed_signal.connect
+      (sigc::mem_fun(*parent, &Group::child_geometry_changed));
+    
+    props_connection = props_changed_signal.connect
+      (sigc::mem_fun(*parent, &Group::child_props_changed));
+  }
 }
 
 Pagent::Resizable::~Resizable() {}
