@@ -23,14 +23,11 @@ TextFrame::TextFrame(Group *parent, TextStream *stream,
     text_stream(stream),
     num_columns(1), gutter_width(12.0), width(w), height(h)
 {
-  white_is_transparent = true;
   ps_exists = false;
   parsed_file_lock = false;
 
   if(text_stream)
     text_stream->add_frame(this);
-  signal_end_write_ps.connect
-    (slot(*this,  &TextFrame::_end_write_ps));
 }
 
 TextFrame::TextFrame(const ElementWrap& xml, Group *parent)
@@ -42,7 +39,6 @@ TextFrame::TextFrame(const ElementWrap& xml, Group *parent)
     width(xml.get_required_attribute<float>("width")),
     height(xml.get_required_attribute<float>("height"))
 {
-  white_is_transparent = true;
   ps_exists = false;
   parsed_file_lock = false;
   
@@ -53,8 +49,6 @@ TextFrame::TextFrame(const ElementWrap& xml, Group *parent)
       throw Error::Read("Failed to get text stream \"" + stream->get_value()
 			+ "\" for text frame");
   } // If stream is not present text_stream is null. This is ok.
-  signal_end_write_ps.connect
-    (slot(*this,  &TextFrame::_end_write_ps));
 }
 
 TextFrame::~TextFrame() {
@@ -127,33 +121,26 @@ void TextFrame::set_stream(TextStream *new_stream,
   ps_exists = false;
   if(text_stream) {
     text_stream->add_frame(this);
-    text_stream->generate_ps_request(this);
   } else {
     // make sure the viewent notices that something happened
-    object_changed_signal(this);
+    object_changed_signal();
   }
   
-  props_changed_signal(this);
-  if(text_stream)
-    text_stream->generate_ps_request(this);
+  props_changed_signal();
 }
 
 void TextFrame::set_num_columns(unsigned int columns) { 
   if(num_columns != columns) {
     num_columns = columns;
     //content_is_broken = false;	// Assume it's ok until we try it
-    props_changed_signal(this);
-    if(text_stream)
-      text_stream->generate_ps_request(this);
+    props_changed_signal();
   }
 }
 
 void TextFrame::set_gutter(const float& gutter) { 
   if(gutter_width != gutter) {
     gutter_width = gutter; 
-    props_changed_signal(this);
-    if(text_stream)
-      text_stream->generate_ps_request(this);
+    props_changed_signal();
   }
 }
 
@@ -161,7 +148,7 @@ void TextFrame::set_size(float w, float h) {
   if(w != width || h != height) {
     width = w; height = h;
     ps_exists = false;
-    geometry_changed_signal(this);
+    geometry_changed_signal();
   }
 }
 
@@ -171,6 +158,7 @@ void TextFrame::begin_write_ps() {
 
 void TextFrame::end_write_ps(bool _ps_exists, bool _truncated,
 			     const std::string &_error) {
+  debug << "*** END_WRITE_PS ***" << std::endl;
   parsed_file_lock = false;
   error = _error;
   ps_exists = _ps_exists;
@@ -178,11 +166,7 @@ void TextFrame::end_write_ps(bool _ps_exists, bool _truncated,
     truncated = _truncated;
     truncated_state_changed_signal(truncated);
   }
-  signal_end_write_ps();
-}
-
-void TextFrame::_end_write_ps() {
-  object_changed_signal(this);
+  object_changed_signal();
 }
 
 void TextFrame::generate_picture(std::ostream& psstream) const {
