@@ -9,8 +9,6 @@
 #include <vector>
 #include <algorithm>
 
-#include <gtkmm/style.h>
-
 #include "document/loader.h"
 #include "document/textframe.h"
 #include "document/imageframe.h"
@@ -23,13 +21,18 @@
 #include "util/filesys.h"
 
 #include "widget/usererror.h"
+#include "widget/programs.h"
 
 #include "groupmeta.h"
 #include "pptcore.h"
-#include "pagesel.h"
 #include "config.h"
 #include "lengthunits.h"
 
+#include "defines.h"
+#ifdef HAVE_GNOME
+#include <libgnomevfs/gnome-vfs-mime.h>
+#endif
+
 float DocumentView::pt2scr(float pt) const {
    return int(resolution * zoom_factor 
 	      * length_units.from_base(pt, "in") + 0.5);
@@ -54,22 +57,6 @@ Vector DocumentView::scr2pt(const Gdk::Point& scr) const {
 
 
 //////////////////////////////////// BEGIN JUNK
-void DocumentView::insert_page_before() {
-  if(document)
-    template_page_dialog->show_it(true, 
-				  document->get_num_of_pages() 
-				  ? current_page_num
-				  : document->get_first_page_num());
-}
-
-void DocumentView::insert_page_after() {
-  if(document)
-    template_page_dialog->show_it(true, 
-				  document->get_num_of_pages()
-				  ? current_page_num + 1
-				  : document->get_first_page_num());
-}
-
 void DocumentView::delete_page() {
   if(document) {
     pageview.clear(); // Do this first, so the viewent won't be
@@ -77,20 +64,12 @@ void DocumentView::delete_page() {
                       // which is emitted after the page has been
                       // deleted.
     document->delete_page(current_page_num);
+    // Todo: this is an ugly fix to keep the pageview updated
+    set_current_page_num(current_page_num);
+    current_page_num_changed_signal(); // sometimes redundant
   }
 }
 
-
-void DocumentView::new_text_frame(TextStream *stream) {
-  Page *page = get_page();
-  if(!page || !document)
-    return;
-  
-  int w = 200, h = 300;
-  // default to the first (alphabetically) stream
-  page->addObject(new TextFrame(page, stream, w, h));
-}
-
 void DocumentView::new_image_frame(std::string filename, float res) {
   Page *page = get_page();
   if(!page)
@@ -110,41 +89,6 @@ void DocumentView::new_image_frame(std::string filename, float res) {
   }
 }
 
-void DocumentView::select_all_frames() {
-  if(Page *page = get_page()) {
-      page->select_all(true); 
-    }
-}
-
-void DocumentView::unselect_all_frames() {
-  if(Page *page = get_page()) {
-      page->select_all(false); 
-    }
-}
-
-void DocumentView::delete_selected() {
-  if(DocRef doc = get_document()) {
-    doc->delete_selected();
-  }
-}  
-
-void DocumentView::group_selected() {
-  if(Page *page = get_page()) {
-    page->group_selected();
-  }
-}
-
-void DocumentView::ungroup_selected() {
-  if(Page *page = get_page()) {
-    page->ungroup_selected();
-  }
-}
-
-void DocumentView::rearrange_selected(RearrangeTarget target) {
-  if(Page *page = get_page()) {
-    page->rearrange_selected(target);
-  }
-}  
 //////////////////////////////////////END JUNK
 
 Page *DocumentView::get_page() {
@@ -200,13 +144,12 @@ void DocumentView::set_current_page_num(int current) {
   }
 }
 
-void DocumentView::update_document_size(DocRef document_) {
-  if(!document || document != document_)
-    return;
+void DocumentView::update_document_size() {
   float w = document->get_width();
   float h = document->get_height();
   
-  reset_scroll_region();
+  set_scroll_region(-margin_size, -h - margin_size,
+                    w + margin_size, margin_size);
   
   no_pages_frame->property_x1() = 0;
   no_pages_frame->property_y1() = 0;
@@ -224,17 +167,17 @@ void DocumentView::set_document(DocMeta d) {
   document = d;
   update_handles();
   if(document) {
-    update_document_size(document.get_document());
+    update_document_size();
     no_pages_group.show();
     
     current_page_num = document->get_first_page_num();
     
-    Document::size_changed_signal.connect
-      (slot(*this, &DocumentView::update_document_size));
+    document->size_changed_signal.connect
+      (sigc::mem_fun(*this, &DocumentView::update_document_size));
     Document::changed_signal.connect
-      (slot(*this, &DocumentView::act_on_document_change));
+      (sigc::mem_fun(*this, &DocumentView::act_on_document_change));
     Document::selection_changed_signal.connect
-      (slot(*this, &DocumentView::act_on_selection_change));
+      (sigc::mem_fun(*this, &DocumentView::act_on_selection_change));
   } else {
     no_pages_group.hide();
   }
@@ -313,18 +256,26 @@ DocumentView::DocumentView(DocMeta d, float zoom_factor)
 
   // Update handles when we turn pages
   current_page_num_changed_signal.connect
-    (slot(*this, &DocumentView::update_handles));
+    (sigc::mem_fun(*this, &DocumentView::update_handles));
+  
+  // make sure the scrolling region is the right size (it only seems
+  // to work if the canvas has been realized)
+  if(document)
+    signal_realize().connect
+      (sigc::mem_fun(*this, &DocumentView::update_document_size));
 }
 
 DocumentView::~DocumentView() {
 }
 
 void DocumentView::set_zoom_factor(float factor) {
-  if(factor > 0 && document) {
+  if(factor > 0) {
       zoom_factor = factor;
       set_pixels_per_unit(resolution / 72.0 * zoom_factor);
-      zoom_change_signal(zoom_factor);
-      update_handles();
+      if(document) {
+        zoom_change_signal(zoom_factor);
+        update_handles();
+      }
     }
 }
 
@@ -386,202 +337,130 @@ int DocumentView::hover_reshape(int x, int y) {
 }
 
 bool DocumentView::on_button_press_event(GdkEventButton *event) {
-  // Cursor-browsing hack:
-  //  static GdkCursorType foo=GdkCursorType(0);
-  //  cerr << foo << endl;
-  //  Gdk::Cursor moving_cursor(foo);
-  //  foo=GdkCursorType(foo+2);
-  //  win.set_cursor(moving_cursor);
-
   Page *page = get_page();
-  if(page && event->button == 1) {
-    const Document::Selection selected = get_document()->selected();
+  if(!page)
+    return true;
 
-    int j = hover_reshape(int(event->x), int(event->y));
-    if(j != -1 && selected.size() == 1
-       && !selected.front()->get_lock()) { // maybe start moving/resizing?
-      // reshape
+  switch(event->button) {
+  case 1:
+    {
+      const Document::Selection selected = get_document()->selected();
 
-      begin_reshape(int(event->x), int(event->y), j);
-    } else if(Pagent* select = in_select_area(int(event->x), int(event->y))) {
-      // select / move
+      int j = hover_reshape(int(event->x), int(event->y));
+      if(j != -1 && selected.size() == 1
+         && !selected.front()->get_lock()) { // maybe start moving/resizing?
+        // reshape
 
-      // is it already selected?
-      if(find(selected.begin(), selected.end(), select) != selected.end()) {
-	if(event->state & Gdk::CONTROL_MASK) { // deselect
-	  get_document()->deselect(select);
-	} else 
-	  begin_move(int(event->x), int(event->y));
-      } else { // select and begin moving
-	get_document()->select(select, !(event->state & Gdk::CONTROL_MASK));
-	if(!select->get_lock())
-	  begin_move(int(event->x), int(event->y));
+        begin_reshape(int(event->x), int(event->y), j);
+      } else if(Pagent* select = in_select_area(int(event->x), int(event->y))) {
+        // select / move
+
+        // is it already selected?
+        if(find(selected.begin(), selected.end(), select) != selected.end()) {
+          if(event->state & Gdk::CONTROL_MASK) { // deselect
+            get_document()->deselect(select);
+          } else
+            begin_move(int(event->x), int(event->y));
+        } else { // select and begin moving
+          get_document()->select(select, !(event->state & Gdk::CONTROL_MASK));
+          if(!select->get_lock())
+            begin_move(int(event->x), int(event->y));
+        }
+      } else if((event->state & Gdk::CONTROL_MASK) == 0) { // deselect all
+        get_document()->select_all(false);
       }
-    } else if((event->state & Gdk::CONTROL_MASK) == 0) { // deselect all
-      get_document()->select_all(false);
     }
+    break;
+  case 3:
+    {
+      if(event->type == GDK_BUTTON_PRESS) {
+        Pagent* select = in_select_area(int(event->x), int(event->y));
+        if(select) {
+          std::string filename;
+          std::vector<std::string> mimetypes;
+
+          /// \todo move the mime type heuristics elsewhere
+          ImageFrame *i_f; RasterFrame *r_f; TextFrame *t_f;
+          if((i_f = dynamic_cast<ImageFrame*>(select))) {
+            filename = i_f->get_association();
+          } else if((r_f = dynamic_cast<RasterFrame*>(select))) {
+            filename = r_f->get_association();
+          } else if((t_f = dynamic_cast<TextFrame*>(select))) {
+            TextStream *stream = t_f->get_stream();
+            filename = stream->get_association();
+            mimetypes.push_back("text/plain"); // always enable text editors
+          } else break;
+
+          if(filename.empty())
+            break;
+#ifdef HAVE_GNOME
+          const char *mtype = gnome_vfs_mime_type_from_name(filename.c_str());
+          if(mtype)
+            mimetypes.push_back(mtype);
+#endif
+          if(mimetypes.empty())
+            mimetypes.push_back("text/plain");
+
+          popup_menu.items().clear();
+          try {
+            for(std::vector<std::string>::const_iterator
+                  type = mimetypes.begin();
+                type != mimetypes.end();
+                type++)
+              Programs::populate_file_handler_menu(popup_menu,
+                                                   filename, *type);
+            popup_menu.popup(event->button, event->time);
+          }
+          catch(const std::exception &e) {
+            verbose << "Failed to display popup menu: " << e.what()
+                    << std::endl;
+          }
+        }
+      }
+    }
+    break;
+  default: break;
   }
 
   return true;
 }
 
-// *** copy/paste stuff ***/
-
 namespace {
-  std::string clip; // a global clip should suffice
-  const std::string pptout_target = "PPTOUT_PAGENTS_2"; // with version number
-}
-
-void DocumentView::copy() {
-  DocRef doc = get_document();
-  if(!doc)
-    return;
-
-  /// \todo make sure the selection is sorted
-  const Document::Selection selected = document->selected();
-  if(selected.empty())
-    return;
-  
-  Glib::RefPtr<Gtk::Clipboard> clipboard = Gtk::Clipboard::get();
-  std::list<Gtk::TargetEntry> target_list;
-  target_list.push_back(Gtk::TargetEntry(pptout_target)); 
-  clipboard->set(target_list, 
-		 SigC::slot(*this, &DocumentView::on_clipboard_get), 
-		 SigC::slot(*this, &DocumentView::on_clipboard_clear));
-
-  // store an XML representation of the selected pagents
-  xmlpp::Document rep;
-  xmlpp::Element *root = rep.create_root_node("copy_data");
-
-  // save relevant streams
-  typedef std::set<const TextStream*> Streams;
-  Streams streams;
-  for(Document::Selection::const_iterator i = selected.begin();
-      i != selected.end(); i++) {
-    const TextFrame *frame = dynamic_cast<const TextFrame *>(*i);
-    if(!frame)
-      continue;
-    const TextStream *stream = frame->get_stream();
-    if(stream && streams.find(stream) == streams.end()) {
-      streams.insert(stream);
-      stream->save(*root, FileContext());
-    }
-  }
-
-  // save pagents
-  for(Document::Selection::const_iterator i = selected.begin();
-      i != selected.end(); i++) {
-    (*i)->save(*root, FileContext());
-  }
-
-  clip = rep.write_to_string();
-  //std::cerr << clip << std::endl;
-}
-
-void DocumentView::on_clipboard_get(Gtk::SelectionData& selection_data, 
-				     guint info)
-{ 
-  const Glib::ustring& target = selection_data.get_target(); 
-  
-  if(target == pptout_target)
-    selection_data.set(pptout_target, clip);
-}
-
-void DocumentView::on_clipboard_clear() {
-  // not really necessary
-  clip.clear(); 
-}
-
-void DocumentView::cut() {
-  copy(); 
-  delete_selected();
-}
-
-void DocumentView::paste() {
-  Page *page = get_page();
-  if(!page)
-    return;
-
-  Glib::RefPtr<Gtk::Clipboard> clipboard = Gtk::Clipboard::get();
-  clipboard->request_contents
-    (pptout_target, SigC::slot(*this, &DocumentView::on_clipboard_received));
-}
-
-void 
-DocumentView::on_clipboard_received(const Gtk::SelectionData& selection_data)
-{
-  Page *page = get_page();
-  if(!page)
-    return;
-
-  Glib::ustring clipboard_data = selection_data.get_data_as_string();
-  try {
-    xmlpp::DomParser parser;  
-    parser.parse_memory(clipboard_data);
-    xmlpp::Element *root = parser.get_document()->get_root_node();
-    if(!root)
-      throw std::runtime_error("Root node is NULL.");
-    xmlpp::Element::NodeList children = root->get_children();
-
-    get_document()->select_all(false);
-    for(xmlpp::Element::NodeList::const_iterator i = children.begin();
-	i != children.end(); i++)
-      {
-	if(xmlpp::Element *elem = dynamic_cast<xmlpp::Element*>(*i)) {
-	  if(elem->get_name() == "text_stream") {
-	    std::auto_ptr<TextStream> stream(new TextStream
-					     (ElementWrap("", *elem)));
-	    // Don't try to add a stream with a name that already exists
-	    /// \todo rename the stream automatically?
-	    if(!document->get_text_stream(stream->get_name()))
-	      document->add_text_stream(stream.release());
-	  } else {
-	    Pagent *pagent = load(ElementWrap("", *elem), page);
-	    page->add(pagent);
-	    get_document()->select(pagent, false); // don't deselect
-	  }
-	}
-      }
-  } catch(const std::exception& e) {
-    throw std::runtime_error("Error encountered when pasting:\n" 
-			     + std::string(e.what()));
-  }
-}  
-
-// Todo: This method should be removed.  Instead, there should exist something
-// (not related to a specific view, but to the document), that listens to
-// geometry changes, finds all text streams that have frames that intersects
-// with the object (before or after the change) and retypesets them.
-// What is done here is to much typsetting when objects moved / resized by the
-// view, and no typesetting at all when objects are moved / resized by e.g.
-// the properties dialog.
-void DocumentView::refresh_streams() {
-  if(Page *page = get_page()) {
-    Document::StreamVec streams;
-    for(Group::ChildVec::const_iterator i = page->pbegin();
-	i != page->pend();
-	i++) 
-      {
-	TextFrame *tmp = dynamic_cast<TextFrame*>(*i);
-	if(tmp) {
-	  TextStream *stream = tmp->get_stream();
-	  if(stream 
-	     && find(streams.begin(), streams.end(), stream) == streams.end())
-	    streams.push_back(stream);
-	}
-      }
-    for(Document::StreamVec::iterator i = streams.begin();
-	i != streams.end();
-	i++)
-      {
-        try {
-          (*i)->run_typesetter();
-        } catch(const BasicFrame::GenPicError &e) {
-          warning << "Failed to refresh stream: " << e.what() << std::endl;
+  // Todo: This method should be removed.  Instead, there should exist something
+  // (not related to a specific view, but to the document), that listens to
+  // geometry changes, finds all text streams that have frames that intersects
+  // with the object (before or after the change) and retypesets them.
+  // What is done here is to much typsetting when objects moved / resized by the
+  // view, and no typesetting at all when objects are moved / resized by e.g.
+  // the properties dialog.
+  void refresh_streams(Page *page) {
+    if(page) {
+      Document::StreamVec streams;
+      for(Group::ChildVec::const_iterator i = page->pbegin();
+          i != page->pend();
+          i++) 
+        {
+          TextFrame *tmp = dynamic_cast<TextFrame*>(*i);
+          if(tmp) {
+            TextStream *stream = tmp->get_stream();
+            if(stream 
+               && find(streams.begin(), streams.end(), stream) == streams.end())
+              streams.push_back(stream);
+          }
         }
-	debug << (*i)->get_name() << ", " 
-	      << (*i)->get_association() << std::endl;
-      }
+      for(Document::StreamVec::iterator i = streams.begin();
+          i != streams.end();
+          i++)
+        {
+          try {
+            (*i)->run_typesetter();
+          } catch(const BasicFrame::GenPicError &e) {
+            warning << "Failed to refresh stream: " << e.what() << std::endl;
+          }
+          debug << (*i)->get_name() << ", " 
+                << (*i)->get_association() << std::endl;
+        }
+    }
   }
 }
 
@@ -613,7 +492,7 @@ void DocumentView::end_reshape(bool revert) {
   if(DocRef document = get_document()) {
     if(revert) {
       const Document::Selection selected = document->selected();
-      if(selected.size() != 1) {
+      if(selected.size() == 1) {
 	Pagent& obj = *selected.front();
 	obj.set_matrix(old_matrix);
 	if(Pagent::Resizable* o = dynamic_cast<Pagent::Resizable*>(&obj)) {
@@ -621,7 +500,7 @@ void DocumentView::end_reshape(bool revert) {
 	}
       }
     }
-    refresh_streams();
+    refresh_streams(get_page());
   }
 }
 
@@ -658,10 +537,8 @@ void DocumentView::begin_move(int x, int y) {
 }
 
 void DocumentView::end_move(bool revert) {
-  if(get_page()) {
-    moving = false;
-    refresh_streams();
-  }
+  moving = false;
+  refresh_streams(get_page());
 }
 
 bool DocumentView::on_key_press_event(GdkEventKey* key) {
@@ -682,7 +559,7 @@ bool DocumentView::on_button_release_event(GdkEventButton *event) {
   return true;
 }
 
-Gdk::Cursor DocumentView::get_cursor(int x, int y) {
+Gdk::CursorType DocumentView::get_cursor(int x, int y) {
   DocRef document = get_document();
   if(!document)
     return Gdk::LEFT_PTR;
@@ -721,7 +598,7 @@ Gdk::Cursor DocumentView::get_cursor(int x, int y) {
 }
 
 void DocumentView::update_cursor(int x, int y) {
-  win->set_cursor(get_cursor(x, y));
+  get_window()->set_cursor(Gdk::Cursor(get_cursor(x, y)));
 }
 
 namespace {
@@ -845,7 +722,7 @@ bool DocumentView::on_motion_notify_event(GdkEventMotion *event) {
   if(event->is_hint) {
     Gdk::ModifierType state;
     int x, y;
-    win->get_pointer(x, y, state);
+    get_window()->get_pointer(x, y, state);
   }
 
   int x = int(event->x);
@@ -899,42 +776,18 @@ bool DocumentView::on_motion_notify_event(GdkEventMotion *event) {
   return true;
 }
 
-void DocumentView::reset_scroll_region() {
-  if(document) {
-    float w = document->get_width();
-    float h = document->get_height();
-    set_scroll_region(-margin_size, -h - margin_size, 
-                      w + margin_size, margin_size);
-  }
-}
-
-void DocumentView::on_realize() {
-  Gnome::Canvas::Canvas::on_realize();
-
-  // Doing this in the constructor does not seem to work all the time
-  reset_scroll_region();
-
-  // get_toplevel doesn't work in the constructor
-  Gtk::Window *toplevel = dynamic_cast<Gtk::Window*>(get_toplevel());
-  assert(toplevel != 0);
-  // template_page_dialog is deleted in the destructor
-  template_page_dialog.reset(new TemplatePageDialog(*toplevel, *this));
-
-  win = get_window();
-}
-
 void DocumentView::on_drag_data_received
-(const Glib::RefPtr<Gdk::DragContext>& context, 
- int x, int y, GtkSelectionData* selection_data, guint info, guint time)
+(const Glib::RefPtr<Gdk::DragContext>& context,
+ int x, int y, const Gtk::SelectionData& selection_data,
+ guint info, guint time)
 {
   /// \todo unicode ???
 
-  Gtk::SelectionData selection(selection_data);
   debug << "DocumentView::on_drop_drag_data_received:" << std::endl
 	<< "x = " << x << ", y = " << y << std::endl
-	<< selection.get_data_type() << " : \"" 
-	<< selection.get_text() << "\"" << std::endl
-	<< "\"" << selection.get_data_as_string() << "\"" << std::endl
+	<< selection_data.get_data_type() << " : \"" 
+	<< selection_data.get_text() << "\"" << std::endl
+	<< "\"" << selection_data.get_data_as_string() << "\"" << std::endl
 	<< std::endl;
 
   if(!get_page()) {
@@ -945,7 +798,7 @@ void DocumentView::on_drag_data_received
   // split into lines
   typedef std::vector<std::string> Strings;
   Strings strings;
-  std::string data = selection.get_data_as_string();
+  std::string data = selection_data.get_data_as_string();
   unsigned int start = 0;
   unsigned int stop;
   unsigned int length = data.length();
@@ -997,10 +850,10 @@ void DocumentView::update_handles() {
     selected_geometry_connection.disconnect();
     selected_props_connection.disconnect();
     selected_geometry_connection = pagent->geometry_changed_signal.connect
-      (SigC::hide<Pagent*>(slot(*this, &DocumentView::update_handles)));
+      (sigc::mem_fun(*this, &DocumentView::update_handles));
     // this is for noticing if the pagent is being locked/unlocked
     selected_props_connection = pagent->props_changed_signal.connect
-      (SigC::hide<Pagent*>(slot(*this, &DocumentView::update_handles)));
+      (sigc::mem_fun(*this, &DocumentView::update_handles));
   }
   ResizeHandles pos = get_resize_handles(*pagent);
   assert(pos.size() == 8);
