@@ -4,13 +4,11 @@
 // Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "metabase.h"
-
-class FileContext;
+#include "util/xmlwrap.h"
 
 class GroupMeta : public MetaBase {
 public:
-  Pagent* load(const xmlpp::Element& node, Group* parent,
-	       const FileContext &context);
+  Pagent* load(const ElementWrap& node, Group* parent);
   
   Viewent::Ref create_viewent(View& view, Pagent& node);
   
