@@ -39,7 +39,7 @@ public:
   const Gdk::Color &get_color(Color::Id color) const { 
     return parent.get_color(color); 
   }
-  SigC::Connection connect_zoom_change(SigC::Slot1<void, float> slot) {
+  sigc::connection connect_zoom_change(sigc::slot<void, float> slot) {
     return parent.connect_zoom_change(slot);
   }
 private:
@@ -53,10 +53,13 @@ GroupViewent::GroupViewent(View& view, const FrameRef groupframe)
     subview(new SubView(view, groupframe->get_matrix(), *content_group)),
     frame(groupframe),
     groupcon(frame->group_changed_signal.connect
-	     (SigC::hide<Pagent*>(slot(*this, &GroupViewent::group_changed))))
+	     (sigc::mem_fun(*this, &GroupViewent::group_changed)))
 {
   // Create the initial content, just as if it was added after this object.
   group_changed();
+  
+  on_geometry_changed();
+  on_properties_changed();
 }
 
 GroupViewent::~GroupViewent() {
