@@ -26,7 +26,7 @@ private:
 
   View* subview;
   FrameRef frame;
-  SigC::Connection groupcon;
+  sigc::connection groupcon;
   ChildVec childvec;
 };
 
