@@ -1,16 +1,15 @@
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "inspiration.h"
 #include "widget/wmisc.h"
+#include "util/warning.h"
 #include <gtkmm/label.h>
 #include <gtkmm/drawingarea.h>
 #include <gtkmm/main.h>
 #include <gtkmm/style.h>
 #include <gtkmm/stock.h>
 #include <gdkmm.h>
-
-#include "safeslot.h"
 #include <util/stringutil.h>
 
 // To build as stand-alone program:
@@ -20,7 +19,7 @@ unsigned int border_width = 12;
 #endif
 
 class Game: public Gtk::DrawingArea {
-  SigC::Connection connection;
+  sigc::connection connection;
   Glib::RefPtr<Gdk::Window> win;
   Glib::RefPtr<Gdk::Visual> visual;
   Glib::RefPtr<Gdk::GC> gc;
@@ -45,7 +44,7 @@ class Game: public Gtk::DrawingArea {
   void put_pixel(Glib::RefPtr<Gdk::Image>, int x, int y, Gdk::Color &color);
   void draw_rect(Gdk::Color &color, bool filled, int x, int y, int w, int h);
 public:
-  SigC::Signal1<void, long> score_change_signal;
+  sigc::signal<void, long> score_change_signal;
   Game();
   bool on_key_press_event(GdkEventKey*);
   void new_game();
@@ -65,7 +64,7 @@ bool Game::on_configure_event(GdkEventConfigure*) {
   if(!(colormap->alloc_color(snake_color)
        && colormap->alloc_color(candy_color)
        && colormap->alloc_color(bg_color)))
-    ; // TODO: report error
+    warning << "Inspiration:  Failed to allocate required colors" << std::endl;
   win = get_window();
   visual = win->get_visual();
 
@@ -208,7 +207,7 @@ void Game::new_game() {
     grow();
   candy_found();
   connection = Glib::signal_timeout().connect
-    (safeslot(*this, &Game::update), 20);  
+    (sigc::mem_fun(*this, &Game::update), 20);  
 }
 
 void Game::stop_game() {
@@ -271,28 +270,33 @@ bool Game::update() {
 //Inspiration
 //**************************
 
+Inspiration *Inspiration::_instance = 0;
+
+Inspiration &Inspiration::instance() {
+  if(!_instance)
+    _instance = new Inspiration();
+  return *_instance;
+}
+
 Inspiration::Inspiration()
-  :DialogWrap("Inspiration")
+  :DialogWrap("Inspiration"), score(manage(new Gtk::Label())), 
+  game(new Game())
 {
   set_events(Gdk::KEY_PRESS_MASK);
-  game = new Game();
   game->set_size_request(320, 240);
   set_border_width(border_width);
   set_resizable(false);
 
-  score = manage(new Gtk::Label());
   get_vbox()->pack_start(*score, Gtk::PACK_EXPAND_PADDING, 0);
   get_vbox()->pack_start(*game, Gtk::PACK_EXPAND_PADDING, 0);
   add_button(Gtk::Stock::CLOSE, 0);
   add_button(Gtk::Stock::EXECUTE, 1);
 
-  game->score_change_signal.connect(safeslot(*this, 
-					     &Inspiration::score_change));
+  game->score_change_signal.connect
+    (sigc::mem_fun(*this, &Inspiration::score_change));
 }
 
-Inspiration::~Inspiration() {
-  delete game;
-}
+Inspiration::~Inspiration() {}
 
 void Inspiration::on_response(int response_id) {
   switch(response_id) {
@@ -318,12 +322,10 @@ void Inspiration::score_change(long score_) {
 }
 
 #ifdef STANDALONE_INSPIRATION
-int main(int argc, char **argv)
-{
+int main(int argc, char **argv) {
   Gtk::Main kit(argc, argv);
   Inspiration inspiration;
   Gtk::Main::run(inspiration);
   return 0;
 }
 #endif
-
