@@ -1,3 +1,6 @@
+///
+// Copyright (C) 2003, 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
+///
 #include "lengthunits.h"
 
 LengthUnits length_units;
@@ -15,5 +18,5 @@ LengthUnits::LengthUnits()
 AngleUnits::AngleUnits()  
   : Units<float, Glib::ustring>(Glib::ustring(1, gunichar(0xb0))) // degrees
 {
-  add_unit("rad", 3.14159265358979323846 / 180); // radians
+  add_unit("rad", 180 / 3.14159265358979323846); // radians
 }
