@@ -9,17 +9,17 @@ PageViewent::PageViewent(View& view, const FrameRef pageframe)
     guide_group(view.get_guide_group())
 {
   Document::selection_changed_signal.connect
-    (slot(*this, &PageViewent::on_selection_changed));
+    (sigc::mem_fun(*this, &PageViewent::on_selection_changed));
   /// \todo maybe let Page throw a size_changed_signal instead?
-  Document::size_changed_signal.connect
-    (slot(*this, &PageViewent::on_size_changed));
+  Document::containing(*page).size_changed_signal.connect
+    (sigc::mem_fun(*this, &PageViewent::on_size_changed));
   
   using namespace Gnome::Canvas;
 
   paper.reset(new Rect(view.get_pagent_group()));
   paper->property_fill_color_gdk() = view.get_color(Color::bg);
   paper->lower_to_bottom();
-  on_size_changed(Document::containing(*page).self());
+  on_size_changed();
 
   float width = page->get_width();
   float height = page->get_height();
@@ -57,10 +57,7 @@ PageViewent::PageViewent(View& view, const FrameRef pageframe)
 PageViewent::~PageViewent() {
 }
 
-void PageViewent::on_size_changed(DocRef doc) {
-  if(doc != Document::containing(*page).self())
-    return;
-
+void PageViewent::on_size_changed() {
   paper->property_x1() = 0; paper->property_y1() = 0;
   paper->property_x2() = page->get_width(); paper->property_y2() = -page->get_height();
 }
