@@ -21,7 +21,7 @@ protected:
   const Pagent* get_frame() const { return page; }
   
 private:
-  void on_size_changed(DocRef doc);
+  void on_size_changed();
   void on_selection_changed(DocRef doc);
 
   FrameRef page;
