@@ -24,7 +24,7 @@ private:
     close_button_str, apply_button_str;//, misc_str;
 
   FileEntry *xslt_entry, *print_entry, *gs_entry, 
-    *ps_entry, *xslt_file_entry;
+    *xslt_file_entry;
   Spinner *resolution_spin, *zoom_spin;
 };
 
