@@ -23,9 +23,7 @@
 #include "widget/errordialog.h"
 
 namespace {
-  const Glib::ustring  ps_format("PostScript"),
-    eps_format("Encapsulated PostScript (EPS)"),
-    pdf_format("Portable Document Format (PDF)");
+  enum {F_PS = 0, F_EPS, F_PDF};
 }
 
 PrintDialog::PrintDialog(Gtk::Window &parent, 
@@ -63,20 +61,12 @@ PrintDialog::PrintDialog(Gtk::Window &parent,
                                                         0.0, 0.5, true));
   format_menu_label->set_mnemonic_widget(format_menu);
   format_menu_box->pack_start(*format_menu_label, Gtk::PACK_SHRINK);
-  {
-    using namespace Gtk;
-    using namespace Menu_Helpers;
-
-    Menu *menu = manage(new Menu());
-    MenuList& menu_list = menu->items();
-    menu_list.push_back(MenuElem(ps_format));
-    menu_list.push_back(MenuElem(eps_format));
-    menu_list.push_back(MenuElem(pdf_format));
-
-    format_menu.set_menu(*menu);
-  }
-  format_menu.get_menu()->signal_selection_done().connect
-    (slot(*this, &PrintDialog::update));
+  format_menu.append_text("PostScript");
+  format_menu.append_text("Encapsulated PostScript (EPS)");
+  format_menu.append_text("Portable Document Format (PDF)");
+  format_menu.set_active(F_PS);
+  format_menu.signal_changed().connect
+    (sigc::mem_fun(*this, &PrintDialog::update));
   format_menu_box->pack_start(format_menu, Gtk::PACK_EXPAND_WIDGET);
 
   Gtk::HBox *using_box = manage(new Gtk::HBox(false, double_space));
@@ -126,12 +116,16 @@ PrintDialog::PrintDialog(Gtk::Window &parent,
   using_entry.set_text(config.PrintCommand.values.front());
   using_button.set_active(true);
 
-  using_button.signal_clicked().connect(slot(*this, &PrintDialog::update));
+  using_button.signal_clicked().connect
+    (sigc::mem_fun(*this, &PrintDialog::update));
   // If there are only two buttons in a group, you only need to connect one.
   // If there are more, you need to connect them all. That is annoying.
-  all_button.signal_clicked().connect(slot(*this, &PrintDialog::update));
-  current_button.signal_clicked().connect(slot(*this, &PrintDialog::update));
-  from_button.signal_clicked().connect(slot(*this, &PrintDialog::update));
+  all_button.signal_clicked().connect
+    (sigc::mem_fun(*this, &PrintDialog::update));
+  current_button.signal_clicked().connect
+    (sigc::mem_fun(*this, &PrintDialog::update));
+  from_button.signal_clicked().connect
+    (sigc::mem_fun(*this, &PrintDialog::update));
 
   add_button(Gtk::Stock::CANCEL, 0);
   add_button(Gtk::Stock::PRINT, 1)->grab_default();
@@ -142,7 +136,7 @@ void PrintDialog::show_it() {
   if(!document)
     return;
   int first = document->get_first_page_num();
-  int last = first + ((int) document->get_num_of_pages()) - 1;
+  int last = first + int(document->get_num_of_pages()) - 1;
   save_state(); 
   from_spinner.limits(first, last);  
   to_spinner.limits(first, last);
@@ -160,30 +154,6 @@ void PrintDialog::show_it() {
   update();
 }
 
-Glib::ustring PrintDialog::get_format() const {
-  if(const Gtk::Label* label
-     = dynamic_cast<const Gtk::Label*>(format_menu.get_child()))
-    return label->get_text();
-  else {
-    warning << "OptionMenu child is not a Label" << std::endl;
-    return "poop";
-  }
-}
-
-void PrintDialog::set_format(const Glib::ustring &format) {
-  using namespace Gtk::Menu_Helpers;
-  MenuList::iterator i;
-  const MenuList &items = format_menu.get_menu()->items();
-  int j;
-  for(i = items.begin(), j = 0; i != items.end(); i++, j++) {
-    const Gtk::Label *label = dynamic_cast<Gtk::Label*>(i->get_child());
-    if(label && label->get_text() == format) {
-      format_menu.set_history(j);
-      return;
-    }
-  }
-}
-
 void PrintDialog::on_response(int response_id) {
   Glib::RefPtr<Gdk::Window> window = get_window();
   if(response_id == 0) {
@@ -221,12 +191,12 @@ void PrintDialog::on_response(int response_id) {
                                  + file_entry.entry.get_text(),
                                  "Check if you have permission "
                                  "to write to this file");
-        window->set_cursor(Gdk::WATCH);
+        window->set_cursor(Gdk::Cursor(Gdk::WATCH));
         // make sure the cursor is updated
         while(Gtk::Main::events_pending())
           Gtk::Main::iteration();
-        Glib::ustring format = get_format();
-        if(format == pdf_format) {
+        int format = format_menu.get_active_row_number();
+        if(format == F_PDF) {
           PDF::Document::Ptr result = PDF::Document::create();
           document->print_pdf(result, first, last);
           result->write(out);
@@ -239,7 +209,7 @@ void PrintDialog::on_response(int response_id) {
                "present in the MacRoman encoding together with Type1 fonts.\n"
                "Passepartout currently lacks full Unicode support for Type1 "
                "fonts when printing to PDF.");
-        } else if(format == eps_format)
+        } else if(format == F_EPS)
           document->print(out,
                           // only the current page
                           document_view.get_current_page_num(),
@@ -290,7 +260,7 @@ void PrintDialog::save_state() {
   saved_file_not_using = file_button.get_active();
   saved_gray = gray_button.get_active();
   saved_fonts = fonts_button.get_active();
-  saved_format = get_format();
+  saved_format = format_menu.get_active_row_number();
 }
 
 void PrintDialog::restore_state() {
@@ -299,7 +269,7 @@ void PrintDialog::restore_state() {
   file_button.set_active(saved_file_not_using);
   gray_button.set_active(saved_gray);
   fonts_button.set_active(saved_fonts);
-  set_format(saved_format);
+  format_menu.set_active(saved_format);
 }
 
 void PrintDialog::update() {
@@ -307,15 +277,15 @@ void PrintDialog::update() {
   file_entry.set_sensitive(file_button.get_active());
   from_spinner.set_sensitive(from_button.get_active());
   to_spinner.set_sensitive(from_button.get_active());
-  Glib::ustring format = get_format();
+  int format = format_menu.get_active_row_number();
   // always include fonts in PDFs
-  fonts_button.set_sensitive(format != pdf_format);
+  fonts_button.set_sensitive(format != F_PDF);
   // grayscale should apply to pdf too, eventually
-  gray_button.set_sensitive(format != pdf_format);
+  gray_button.set_sensitive(format != F_PDF);
   // eps format always prints the current page only
-  pages_box->set_sensitive(format != eps_format);
+  pages_box->set_sensitive(format != F_EPS);
   std::string suffix = ".ps";
-  if(format == pdf_format) suffix = ".pdf";
-  else if(format == eps_format) suffix = ".eps";
+  if(format == F_PDF) suffix = ".pdf";
+  else if(format == F_EPS) suffix = ".eps";
   file_entry.entry.set_text(no_suffix(file_entry.entry.get_text()) + suffix);
 }
