@@ -10,7 +10,7 @@
 #include <gtkmm/radiobutton.h>
 #include <gtkmm/checkbutton.h>
 #include <gtkmm/entry.h>
-#include <gtkmm/optionmenu.h>
+#include <gtkmm/comboboxtext.h>
 
 class DocumentView;
 
@@ -24,18 +24,17 @@ private:
     all_button, current_button, from_button;
   Gtk::CheckButton fonts_button, gray_button;
   Gtk::Entry using_entry;
-  Gtk::OptionMenu format_menu;
+  Gtk::ComboBoxText format_menu;
   Gtk::Widget *pages_box;
   Spinner from_spinner, to_spinner;
   DocumentView &document_view; // document_view keeps record of the document
   FileEntry file_entry;
   Filesel *filesel;
 
-  std::string saved_file_text, saved_using_text, saved_format;
+  std::string saved_file_text, saved_using_text;
+  int saved_format;
   bool saved_file_not_using, saved_eps, saved_gray, saved_fonts;
 
-  Glib::ustring get_format() const;
-  void set_format(const Glib::ustring &format);
   void on_response(int response_id);
   void save_state(); // in case cancel is pressed we will restore inital state
   void restore_state();
