@@ -23,7 +23,7 @@ void PropBase::set_sensitive(bool sensitive) {
   // one. I think this has to do with Gtk::Entry having its own
   // window.
   if(!sensitive)
-    foreach(slot(hide_widget));
+    foreach(sigc::ptr_fun(hide_widget));
 }
 
 void PropBase::right_justify(Gtk::Label &label) {
