@@ -39,7 +39,7 @@ private:
   // no destructor
   ~PropertiesDialog();
 
-  void PropertiesDialog::show_page_contents(GtkNotebookPage*, guint index);
+  void show_page_contents(GtkNotebookPage*, guint index);
 
   Gtk::Notebook book;
   std::vector<PropBase*> pages;
