@@ -14,8 +14,8 @@ public:
 protected:
   const Pagent* get_frame() const { return frame; }
   
-  void on_object_changed(Pagent*);
-  void on_geometry_changed(Pagent*);
+  void on_object_changed();
+  void on_geometry_changed();
   
 private:
   FrameRef frame;
