@@ -4,10 +4,11 @@
 // Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "metabase.h"
+#include "util/xmlwrap.h"
 
 class TextMeta : public MetaBase {
 public:
-  Pagent* load(const xmlpp::Element& node, Group* parent);
+  Pagent* load(const ElementWrap& xml, Group* parent);
 
   Viewent::Ref create_viewent(View& view, Pagent& node);
   
