@@ -10,16 +10,17 @@
 
 TextViewent::TextViewent(View& view, const FrameRef cachedframe,
 			 int scale_factor)
-  : PostscriptViewent(view, cachedframe, scale_factor)
+  : PostscriptViewent(view, cachedframe, scale_factor),
+    textframe(dynamic_cast<TextFrame*>(cachedframe))
 {
   Gnome::Canvas::Polygon *tri = new Gnome::Canvas::Polygon(*group);
 
   tri->property_fill_color_gdk() = view.get_color(Color::guide);
   trunc_ind.reset(tri);
   trunc_ind->hide();
-  on_geometry_changed(cachedframe);
-  dynamic_cast<TextFrame*>(cachedframe)->truncated_state_changed_signal.connect
-    (slot(*this, &TextViewent::on_truncated_state_changed));
+  on_geometry_changed();
+  textframe->truncated_state_changed_signal.connect
+    (sigc::mem_fun(*this, &TextViewent::on_truncated_state_changed));
 }
 
 void TextViewent::on_truncated_state_changed(bool truncated) {
@@ -29,10 +30,10 @@ void TextViewent::on_truncated_state_changed(bool truncated) {
     trunc_ind->hide();
 }
 
-void TextViewent::on_geometry_changed(Pagent* pagent) {
-  PostscriptViewent::on_geometry_changed(pagent);
+void TextViewent::on_geometry_changed() {
+  PostscriptViewent::on_geometry_changed();
 
-  Vector size = pagent->get_inherent_size();
+  Vector size = get_frame()->get_inherent_size();
 
   Gnome::Canvas::Polygon *tri =
     dynamic_cast<Gnome::Canvas::Polygon*>(trunc_ind.get());
@@ -43,3 +44,9 @@ void TextViewent::on_geometry_changed(Pagent* pagent) {
   points.push_back(Point(size.x - 15, + 5));
   tri->property_points() = points;
 }
+
+void TextViewent::on_properties_changed() {
+  TextStream *stream = textframe->get_stream();
+  if(stream)
+    stream->generate_ps_request(textframe);
+}
