@@ -5,6 +5,8 @@
 ///
 #include "postscriptviewent.h"
 
+class TextFrame;
+
 class TextViewent : public PostscriptViewent {
 public:
   /**
@@ -18,8 +20,10 @@ public:
 	      int scale_factor = 1);
 
 private:
+  TextFrame *textframe;
   std::auto_ptr<Gnome::Canvas::Item> trunc_ind;
-  void on_geometry_changed(Pagent*);
+  void on_geometry_changed();
+  void on_properties_changed();
   void on_truncated_state_changed(bool);
 };
 
