@@ -8,7 +8,7 @@
 #include <libgnomecanvasmm.h>
 
 namespace Color {
-  typedef enum Id { bg, frame, locked, guide, empty };
+  typedef enum { bg, frame, locked, guide, empty } Id;
 }
 
 class View {
