@@ -5,6 +5,7 @@
 ///
 #include "view.h"
 #include "document/pagent.h"
+#include "util/refcount.h"
 #include <memory> // auto_ptr
 
 /**
@@ -13,7 +14,7 @@
  * Pagent.  When a View is rescaled etc, all its Viewent s are dropped
  * and new ones created.
  */
-class Viewent : public SigC::Object {
+class Viewent : public sigc::trackable, public RefCounted {
 public:
   typedef Glib::RefPtr<const Gdk::Pixmap> PixmapRef;
   typedef Glib::RefPtr<Viewent> Ref;
@@ -43,8 +44,8 @@ protected:
    * (or no icon if the state is NORMAL). */
   virtual void set_state(State state);
 
-  virtual void on_geometry_changed(Pagent* pagent);
-  virtual void on_properties_changed(Pagent* pagent);
+  virtual void on_geometry_changed();
+  virtual void on_properties_changed();
 
 private:
 
