@@ -13,29 +13,22 @@ DialogWrap::DialogWrap(const Glib::ustring& name, Gtk::Window& parent)
 		parent, true /* modal */, false /* separator */)
 {}
 
-void DialogWrap::show_raise() {
-  Glib::RefPtr<Gdk::Window> win = get_window();
-  win->show();			// uniconify if necessary
-  win->raise();			// raise if necessary
-}
+void DialogWrap::show_raise() { present(); }
 
 Gtk::Button* DialogWrap::fix_button(Gtk::Button* button, int action_id) {
   Gtk::Button *b = manage(button);
   // Note: It seems that activate means "in any way except a simple click".
   // So we have to add callbacks for both activate and clicked.
-  b->signal_clicked().connect(bind(slot(*this, &Gtk::Dialog::on_response),
-				   action_id));
-  b->signal_activate().connect(bind(slot(*this, &Gtk::Dialog::on_response),
-				    action_id));
+  b->signal_clicked().connect
+    (bind(sigc::mem_fun(*this, &DialogWrap::on_response), action_id));
+  b->signal_activate().connect
+    (bind(sigc::mem_fun(*this, &DialogWrap::on_response), action_id));
   return b;
 }
 
 UtilityWindow::UtilityWindow(const Glib::ustring& name) {
+  set_type_hint(Gdk::WINDOW_TYPE_HINT_UTILITY);
   set_title(name + " - Passepartout");
 }
 
-void UtilityWindow::show_raise() {
-  Glib::RefPtr<Gdk::Window> win = get_window();
-  win->show();			// uniconify if necessary
-  win->raise();			// raise if necessary
-}
+void UtilityWindow::show_raise() { present(); }
