@@ -5,18 +5,14 @@
 ///
 #include <gtkmm/dialog.h>
 
-/**
- * A helper class to do create nice and uniform dialogs in passepartout.  The
- * main focus is for subclasses to be HIG compliant without having to have
- * lots of extra code.
- */
+/** A base class for creating uniform dialog windows. */
 class DialogWrap : public Gtk::Dialog {
 protected:
   /** Create a non-modal dialog */
-  DialogWrap(const std::string& name);
+  DialogWrap(const Glib::ustring& name);
 
   /** Create a modal dialog */
-  DialogWrap(const std::string& name, Gtk::Window& parent);
+  DialogWrap(const Glib::ustring& name, Gtk::Window& parent);
 
   /**
    * Show and raise the dialog, so it is surely visible.
@@ -31,5 +27,15 @@ protected:
   Gtk::Button* fix_button(Gtk::Button* button, int action_id);
 };
 
-#endif
+/** A base class for creating uniform utility windows. The difference
+ *  between a utility window and a dialog is that a utility window
+ *  never is modal and doesn't have action buttons at the bottom. */
+class UtilityWindow : public Gtk::Window {
+protected:
+  UtilityWindow(const Glib::ustring& name);
 
+  /** Show and raise the window, so it is surely visible. */
+  virtual void show_raise();
+};
+
+#endif
