@@ -5,8 +5,9 @@
 #ifndef FILESEL_H
 #define FILESEL_H
 
-#include <gtkmm/fileselection.h>
-#include <gtkmm/combo.h>
+#include <gtkmm/filechooserdialog.h>
+#include <gtkmm/comboboxentrytext.h>
+#include <gtkmm/entry.h>
 #include <memory>
 
 class Filesel;
@@ -16,11 +17,12 @@ class Filesel;
  * in the pop-down menu. Also the cursor is moved to the end when the
  * text is set.
  */
-class EndEntry: public Gtk::Combo {
+class EndEntry: public Gtk::ComboBoxEntryText {
 public:
   EndEntry(int _history_max = 5);
-  void set_text(const Glib::ustring &text);
+  void set_text(const Glib::ustring &text, bool remember_text = false);
   Glib::ustring get_text(bool remember_text = true);
+  Gtk::Entry& get_entry();
   void remember(); // add current text to history
 private:
   unsigned int history_max;
@@ -36,7 +38,7 @@ public:
   EndEntry entry;
   FileEntry(const Glib::ustring& window_title_, 
 	    const Glib::ustring& default_path_ = "", 
-	    const bool file_prompt_ = true);
+            Gtk::FileChooserAction action = Gtk::FILE_CHOOSER_ACTION_OPEN);
 
   const Glib::ustring& get_default_value(); 
   //set entry text to value. default_path is still going to be used 
@@ -51,7 +53,7 @@ private:
   Glib::ustring *default_value;
   Gtk::Button button;
   std::auto_ptr<Filesel> filesel;
-  bool file_prompt;
+  Gtk::FileChooserAction action;
 
   void filesel_done();
   void show_filesel();
@@ -61,18 +63,15 @@ private:
  * A file selection dialog with response handlers connected to the
  * ok/cancel buttons.
  */
-class Filesel: public Gtk::FileSelection {
+class Filesel: public Gtk::FileChooserDialog {
 public:
-  /**
-   * \param _accept_nonexistent If false, reject files that do not exist.
-   */
-  Filesel(Gtk::Window &parent, const Glib::ustring& title, 
-	  bool _accept_nonexistent = false, bool _accept_dir = false);
-  bool was_cancelled() const {return cancelled;}
+  Filesel(Gtk::Window &parent, const Glib::ustring& title,
+          Gtk::FileChooserAction action = Gtk::FILE_CHOOSER_ACTION_OPEN);
+  bool was_cancelled() const { return cancelled; }
   
 private:
   void on_response(int response_id);
-  bool cancelled, accept_nonexistent, accept_dir;
+  bool cancelled;
 };
 
 #endif
