@@ -31,8 +31,11 @@ class ImageFilesel: public Filesel {
   struct { ustring name;  float factor; } unit; 
   Gtk::Image preview;
   struct { int width, height; } image_size;
-  Gtk::CheckButton show_preview;
-  Gtk::Label no_preview, info;
+  Gtk::Label info;
+  Glib::RefPtr<Gdk::Pixbuf> pixbuf;
+  Glib::Dispatcher signal_loaded;
+  void start_loader();
+  void loader_thread();
   void update_preview();
   void update_size();
 };
