@@ -125,16 +125,11 @@ namespace PS {
     // Conversion from a four-digit base 256 number 
     // to a five-digit base 85 number.
     // number should be at least a 32 bit number
-    unsigned long number =
-      (((unsigned long) chunk[0]) << 24)
-      + (((unsigned long) chunk[1]) << 16)
-      + (((unsigned long) chunk[2]) << 8)
-      + (((unsigned long) chunk[3]));
-      //      chunk[0] * 16777216 // 256^3
-      //      + chunk[1] * 65536  // 256^2
-      //      + chunk[2] * 256    // 256^1
-      //      + chunk[3];         // 256^0
-    
+    unsigned long number = 0;
+    for(int i = 0; i < 4; i++) {
+      number <<= 8;
+      number |= chunk[i];
+    }
 
     out_chunk[0] = number / 52200625; // 85^4
                   number %= 52200625;
