@@ -1,10 +1,11 @@
 // -*- c++ -*-
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #ifndef ENCODE_H 
 #define ENCODE_H
 
+#include <cstring>
 #include <iostream>
 #include <string>
 #include <vector>
@@ -72,12 +73,12 @@ namespace PS {
     virtual void init() {line_width = 0;}
   };
 
-  typedef std::vector<SimpleEncodeFilter*> Filter_Sequence;
+  typedef std::vector<SimpleEncodeFilter*> FilterSequence;
 
   // more than one (simple) filter after one another
   class EncodeFilterCascade: public EncodeFilter {
   public:
-    EncodeFilterCascade(Filter_Sequence &filter_sequence):
+    EncodeFilterCascade(FilterSequence &filter_sequence):
       sequence(filter_sequence) 
     {}
     std::string decode_command() const;
@@ -86,7 +87,7 @@ namespace PS {
 	       bool flush = false);
 
   private:
-    Filter_Sequence &sequence;
+    FilterSequence &sequence;
   };
 
   // Simple binary-to-ASCII filter
