@@ -1,7 +1,7 @@
 #ifndef PUTIL_BARRIER_H		// -*- c++ -*-
 #define PUTIL_BARRIER_H
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include <glibmm/thread.h>
 
@@ -38,9 +38,9 @@ public:
 private:
   Glib::Mutex mutex;
   Glib::Cond cond;
-  bool is_open;
+  volatile bool is_open;
 
-  // Unefined - fobidden
+  // Undefined - forbidden
   Barrier(const Barrier&);
   Barrier& operator = (const Barrier&);
 };
