@@ -19,7 +19,7 @@ void BoolVar::print(std::ostream &out) const {
 
 void BoolVar::parse(const std::string &input) {
   Bools tmp;
-  std::istringstream in(input.c_str());
+  std::istringstream in(input);
   while(in) {
     std::string word;
     in >> word;
@@ -123,7 +123,7 @@ void FloatVar::print(std::ostream &out) const {
 
 void FloatVar::parse(const std::string &input) {
   Floats tmp;
-  std::istringstream in(input.c_str());
+  std::istringstream in(input);
   float value;
   while(in >> value)
     tmp.push_back(value);
