@@ -13,6 +13,8 @@
 #ifndef HAVE_MKDTEMP
 #include <sys/types.h>
 #endif
+#include <cstdlib>
+#include <cstring>
 
 using std::string;
 
