@@ -13,7 +13,7 @@ namespace FAM { class File; }
 /// Monitor a file for changes.
 /** Uses the File Alteration Monitor from SGI if available, otherwise
  * it calls stat(2) on the file at regular intervals. */
-class FileWatcher: public SigC::Object {
+class FileWatcher: public sigc::trackable {
 public:
   /**
    * \param filename File to watch. Must be an absolute path.
@@ -23,13 +23,13 @@ public:
   void set_file(const std::string &filename);
 
   /// Signal emitted each time a change is detected.
-  SigC::Signal0<void> modified_signal;
+  sigc::signal<void> modified_signal;
 
 protected:
   std::string file;
   time_t last_time;
   std::auto_ptr<FAM::File> famfile;
-  SigC::Connection connection;
+  sigc::connection connection;
   bool check_file();
 
 private:
