@@ -3,6 +3,7 @@
 ///
 #include "matrix.h"
 #include "typeinfo.h"
+#include <libgnomecanvasmm/affinetrans.h>
 #include <iostream>
 #include <cmath>
 
@@ -47,10 +48,18 @@ Matrix Matrix::translation(double xoffset, double yoffset) {
 
 Matrix Matrix::shearing(double shcoeff) {
   Matrix tmp;
-  tmp.rep[2] = shcoeff;
+  tmp.rep[2] = tan(shcoeff);
   return tmp;
 }
 
+const Gnome::Art::AffineTrans Matrix::gaTransform() const {
+  using Gnome::Art::AffineTrans;
+  return (AffineTrans::shearing(-rad2deg(sh()))
+	  * AffineTrans::scaling(sc_x(), sc_y())
+	  * AffineTrans::rotation(-rad2deg(rot()))
+	  * AffineTrans::translation(tr_x(), -tr_y()));
+}
+
 bool Matrix::is_plain() const {
   const float epsilon = 1e-5;
   return (abs(rep[2]) <= epsilon && abs(rep[1]) <= epsilon &&
@@ -101,9 +110,9 @@ double Matrix::sc_y() const {
 
 double Matrix::sh() const {
   if(a() != 0)
-    return (c() + sc_y() * sin(rot())) / a();
+    return atan2(c() + sc_y() * sin(rot()), a());
   else // if(b() != 0) an exception should occur before we get division by zero
-    return (d() - sc_y() * cos(rot())) / b();
+    return atan2(d() - sc_y() * cos(rot()), b());
 }
 
 Matrix& Matrix::set_tr_x(double val) {
@@ -195,9 +204,14 @@ Matrix Matrix::operator * (const Matrix& m) const {
   return tmp;
 }
 
+namespace {
+  const double epsilon = 1e-6; /// \note this is rather arbitrary
+  bool almost_equal(double a, double b) { return abs(a - b) < epsilon; }
+}
+
 bool Matrix::operator == (const Matrix& m) const {
   for(int i = 0; i < 6; ++i)
-    if(rep[i] != m.rep[i]) return false;
+    if(!almost_equal(rep[i], m.rep[i])) return false;
 
   return true;
 }
