@@ -1,11 +1,14 @@
 #ifndef MATRIX_H		// -*- c++ -*-
 #define MATRIX_H
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "vector.h"
 #include <stdexcept>
 
+// forward declaration
+namespace Gnome { namespace Art { class AffineTrans; } }
+
 namespace Error {
   struct SingularMatrix : public std::runtime_error {
     SingularMatrix(const std::string& when)
@@ -40,7 +43,14 @@ struct Matrix
   static Matrix rotation(double angle);
   static Matrix translation(const Vector& offset);
   static Matrix translation(double xoffset, double yoffset);
-
+  
+  /**
+   * Get this same transform in Gnome::Art format.
+   * Due to differences in reference system, the transforms are kind of
+   * reverse copies of each other.
+   */
+  const Gnome::Art::AffineTrans gaTransform() const;
+  
   // making sense out of matrices:
   // may throw Error::SingularMatrix
   bool is_plain() const;	// true iff this is only scale and translate.
