@@ -67,12 +67,12 @@ private:
 typedef Glib::RefPtr<ProcessRecord> Process;
 
 //This is a singleton
-class ProcessManager: public SigC::Object {
+class ProcessManager: public sigc::trackable {
 public:
   // Signal that a process has stopped,
   // attach process id, a bool to signify normal termination
   // and an exit code that is only meaningful if the bool is true:
-  SigC::Signal3<void, pid_t, bool, int> process_stopped;
+  sigc::signal<void, pid_t, bool, int> process_stopped;
 
   static ProcessManager &instance();
 
