@@ -10,7 +10,9 @@
  * correct measurments.
  */
 void testProcessIO() {
-  Process proc = ProcessManager::instance().run("wc");
+  std::vector<std::string> cmd;
+  cmd.push_back("wc");
+  Process proc = ProcessManager::instance().run(cmd);
   proc->get_cin() << "Foo bar" << std::endl
 		  << "baz" << std::endl;
   proc->close_cin();
