@@ -1,12 +1,12 @@
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "boundaries.hh"
 #include <stdexcept>
 #include <sstream>
 
-xml2ps::PageSize::PageSize(const std::string& s)
-  : gutter_(10), columns_(1) 
+xml2ps::PageSize::PageSize(int num, const std::string& s)
+  : gutter_(10), columns_(1), num_(num)
 {
   using std::runtime_error;
   std::istringstream in(s);
@@ -22,9 +22,9 @@ xml2ps::PageSize::PageSize(const std::string& s)
   }
 }
 
-xml2ps::PageSize::PageSize(float width, float height, 
+xml2ps::PageSize::PageSize(int num, float width, float height, 
 			   int columns, float gutter) :
-  width_(width), height_(height), gutter_(gutter), columns_(columns)
+  width_(width), height_(height), gutter_(gutter), columns_(columns), num_(num)
 {}
 
 
