@@ -1,5 +1,5 @@
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "canvas.hh"
 #include "util/rectboundary.h"
@@ -22,7 +22,7 @@ void xml2ps::Canvas::newPage() {
   
   if(cur_page_ == pages_.end()) {
     if(!allow_extra_pages_)
-      throw out_of_pages();
+      throw OutOfPages();
     if(op == PageVec::iterator(0))
       throw std::runtime_error("No pages specified");
     cur_page_ = op;
@@ -116,7 +116,7 @@ xml2ps::Canvas::addRelObstacle(const float left, const float bottom,
 xml2ps::HBox xml2ps::Canvas::hbox(bool span, float margin_left,
 				  float margin_right, 
 				  float ascender, float descender) {
-  const float minimum_width = 10.0;// Todo: Don't hardcode this!
+  const float minimum_width = 10.0;/// \todo Don't hardcode this!
   HBox result;
   do {
     reserveHeight(ascender + descender, span);
