@@ -1,5 +1,5 @@
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "line.hh"
 
@@ -22,7 +22,7 @@ xml2ps::Line::add(xml2ps::Node* node) {
   // Container Elements must be split into pieces, or the
   // width calculations might go wrong:
   if(const Element* element = dynamic_cast<const Element*>(node))
-    if(element->begin()!=element->end())
+    if(element->begin() != element->end())
       return false; 
 
   if(dynamic_cast<const LineBreak*>(last_node)) {
@@ -31,7 +31,8 @@ xml2ps::Line::add(xml2ps::Node* node) {
   }
 
   bool force = !first_node;
-  if(force) first_node = node;
+  if(force) 
+    first_node = node;
   
   float twidth = node->getWidth();
   if(dynamic_cast<const WhiteSpaceNode*>(node)) {
@@ -40,8 +41,8 @@ xml2ps::Line::add(xml2ps::Node* node) {
     return true;
   } else {
     // This is a factor, not a width in points or something ...
-    const float max_wordspace = 4.0; // Todo: read this number somewhere!
-    const float min_wordspace = 0.5; // Todo: Also configurable ...
+    const float max_wordspace = 4.0; /// \todo read this number somewhere!
+    const float min_wordspace = 0.5; /// \todo Also configurable ...
     const float sw(((hbox.room() - text_width) / space_width) > max_wordspace
 		   ? space_width * min_wordspace
 		   : space_width);
@@ -82,7 +83,7 @@ void xml2ps::Line::flush(bool is_last) {
 		      :((align == Element::right)
 			? hbox.right() - text_width - space_width
 			: hbox.left()));
-  const float max_wsw = 3;	// Todo: Get from attribute
+  const float max_wsw = 3;	/// \todo Get from attribute
   float wsw = ((!is_last && !is_linebreak && align == Element::justify)
 	       ? (space_width > 0
 		  ? ((hbox.room() - text_width) / space_width)
@@ -96,7 +97,7 @@ void xml2ps::Line::flush(bool is_last) {
     
     wsw = max_wsw;
     float desired_text_width = hbox.room() - space_width * wsw;
-    if(count.first>1)
+    if(count.first > 1)
       charw = (desired_text_width - text_width)
 	/ (count.first - 1 + count.second * wsw);
   }
