@@ -7,6 +7,8 @@
 #include <sstream>
 #include <iostream>
 #include <vector>
+#include <exception>
+#include <memory>
 
 xml2ps::PagedStream::PagedStream() 
   : current_part(0)
@@ -39,12 +41,7 @@ void xml2ps::PagedStream::appendPage(unsigned int number, std::ostream& out)
 {
   const std::string inname = filename(number);
   std::ifstream in(inname.c_str());
-  const size_t blocksize = 4*1024; /// \todo  Value?
-  std::vector<char> buf(blocksize);  // use string instead?
-  while(in.read(&buf[0], buf.size())) {
-    out.write(&buf[0], in.gcount());
-  }
-  out.write(&buf[0], in.gcount());
+  out << in.rdbuf();
 }
 
 std::string xml2ps::PagedStream::filename(unsigned int number) const {
