@@ -1,5 +1,5 @@
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include <util/stringutil.h>
 #include "paragraph.hh"
@@ -10,11 +10,11 @@
 xml2ps::Paragraph::Paragraph(Canvas& out, Element& parent,
 			     const Glib::ustring& n, const Attributes attr)
   : TextContainer(parent, n, attr), out_(out),
-    margin_top(attr.get("margin-top", 0)),
-    margin_bottom(attr.get("margin-bottom", 0)),
-    margin_left(attr.get("margin-left", 0)),
-    margin_right(attr.get("margin-right", 0)),
-    line_height(attr.get("line-height", 1)),
+    margin_top(attr.get("margin-top", 0, getFontSize())),
+    margin_bottom(attr.get("margin-bottom", 0, getFontSize())),
+    margin_left(attr.get("margin-left", 0, getFontSize())),
+    margin_right(attr.get("margin-right", 0, getFontSize())),
+    line_height(attr.get("line-height", 1, getFontSize())),
     spancolumns(attr.get("span-columns", false))
 {}
 
