@@ -9,7 +9,7 @@
 
 xml2ps::PsCanvas::PsCanvas(const PageVec& pages,
 			   bool allow_extra_pages)
-  : Canvas(pages, allow_extra_pages)
+  : Canvas(pages, allow_extra_pages), cur_rise(0)
 {
   newPage();
 }
@@ -21,6 +21,10 @@ void xml2ps::PsCanvas::newPage() {
   PsStream::newPage(int(cur_page_->width()+0.5), int(cur_page_->height()+0.5));
 }
 
+void xml2ps::PsCanvas::closePage() {
+  flush();
+}
+
 void xml2ps::PsCanvas::setgray(float gray) {
   (*this) << gray << " setgray\n";
 }
@@ -44,6 +48,24 @@ void xml2ps::PsCanvas::moverel(float dx, float dy) {
   (*this) << dx << ' ' << dy << " rmoveto\n";
 }
 
+float xml2ps::PsCanvas::textRise(float rise) {
+  float oldrise = cur_rise;
+  float change = rise - cur_rise;
+  cur_rise = rise;
+  moverel(0, change);
+  return oldrise;
+}
+
+void xml2ps::PsCanvas::setWordSpace(const float& space) {
+  // the space parameter is in "times normal width of whitespace"
+  // word_space is in points.
+  word_space = font_->getWidth(" ") * space;
+}
+
+float xml2ps::PsCanvas::getRise() const {
+  return cur_rise;
+}
+
 void xml2ps::PsCanvas::show(const Glib::ustring& text) {
   const float ls = font_->getLetterSpacing();
 
@@ -87,6 +109,10 @@ void xml2ps::PsCanvas::show(const Glib::ustring& text) {
   }
 }
 
+void xml2ps::PsCanvas::whitespace() {
+  (*this) << word_space << " WS ";
+}
+
 void xml2ps::PsCanvas::whitespace(const float& space) {
   (*this) << space << " WS ";
 }
