@@ -1,5 +1,5 @@
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include <iostream>
 #include "xly.hh"
@@ -18,16 +18,20 @@ xml2ps::Attributes::get(const Glib::ustring& name,
 			const Glib::ustring& defaultvalue) 
   const 
 {
-  xmlpp::SaxParser::AttributeMap::const_iterator i = p_.find(name);
-  return i != p_.end() ? Glib::ustring(i->second) : defaultvalue;
+  using namespace xmlpp;
+  SaxParser::AttributeList::const_iterator i =
+    std::find_if(p_.begin(), p_.end(), SaxParser::AttributeHasName(name));
+  return i != p_.end() ? Glib::ustring(i->value) : defaultvalue;
 }
 
 float
 xml2ps::Attributes::get(const Glib::ustring& name, const float& defaultvalue,
 			const float embase) const {
-  xmlpp::SaxParser::AttributeMap::const_iterator i = p_.find(name);
+  using namespace xmlpp;
+  SaxParser::AttributeList::const_iterator i =
+    std::find_if(p_.begin(), p_.end(), SaxParser::AttributeHasName(name));
   if ( i != p_.end() ) {
-    ValueUnit<float> value = to<ValueUnit<float> >(i->second);
+    ValueUnit<float> value = to<ValueUnit<float> >(i->value);
     if(value.unit() == "" || value.unit() == "pt")
       return value.value();
     else if(value.unit() == "%")
@@ -40,7 +44,7 @@ xml2ps::Attributes::get(const Glib::ustring& name, const float& defaultvalue,
       else return value.value() * defaultvalue;
     } else {
       std::cerr << "Bad unit: ''" <<  value.unit() << "'' in ''"
-		<< i->second << "''" << std::endl;
+		<< i->value << "''" << std::endl;
       throw std::runtime_error("Bad ''unit'': " + value.unit());
     }
   } else
@@ -61,7 +65,6 @@ xml2ps::Node::nodeBefore() const {
 const font::FontInfo&
 xml2ps::TextNode::getFont() const { return getParent().getFont(); }
 
-
 // - - - Element - - -
 
 template<>
@@ -129,7 +132,7 @@ xml2ps::Element::getWidth() const {
   for(NodeVect::const_iterator i = nodes.begin(); i != nodes.end(); ++i)
     width += (*i)->getWidth();
 
-  // Todo: Add support for margins / padding ...
+  /// \todo Add support for margins / padding ...
   return width;
 }
 
@@ -152,12 +155,14 @@ namespace {
   class BaseShift {
   public:
     BaseShift(xml2ps::Canvas& c, const float& shift)
-      : canvas(c), dy(shift)
-      { canvas.moverel(0, dy); }
-    ~BaseShift() { canvas.moverel(0, -dy); }
+      : canvas(c), oldvalue(canvas.getRise())
+    {
+      canvas.textRise(oldvalue + shift);
+    }
+    ~BaseShift() { canvas.textRise(oldvalue); }
   private:
     xml2ps::Canvas& canvas;
-    float dy;
+    float oldvalue;
   };
 }
 
@@ -212,6 +217,7 @@ xml2ps::Element::printPart(Canvas& canvas, const Node* from, const Node* to,
   
   const font::FontInfo font = font::FontInfo::WidenFont(getFont(), cwidth);
   canvas.setfont(font);
+  canvas.setWordSpace(whitewidth); // after setting font
   canvas.setgray(gray);
   std::auto_ptr<Underline> ul(underline? new Underline(canvas, font): 0);
   std::auto_ptr<BaseShift> bs(baseline!=0? new BaseShift(canvas, baseline): 0);
@@ -220,7 +226,7 @@ xml2ps::Element::printPart(Canvas& canvas, const Node* from, const Node* to,
   for(NodeVect::const_iterator i = start; i != end; ++i) {
     n = *i;
     if(dynamic_cast<WhiteSpaceNode*>(*i)) {
-      canvas.whitespace(font.getWidth(" ") * whitewidth);
+      canvas.whitespace();
       
     } else if(TextNode* tn = dynamic_cast<TextNode*>(*i)) {
       canvas.show(tn->getContent());
@@ -241,6 +247,13 @@ xml2ps::Element::printPart(Canvas& canvas, const Node* from, const Node* to,
 Glib::ustring
 xml2ps::Element::d() const { return name + "(" + tostr(nodes.size()) + ")"; }
 
+// - - - PageBreak - - -
+
+xml2ps::PageBreak::PageBreak(Element& parent, Canvas& out)
+  : Element(parent, "pagebreak", Attributes(xmlpp::SaxParser::AttributeList()))
+{
+  out.newPage();
+}
 
 // - - - BreakPoint - - -
 
@@ -258,7 +271,7 @@ xml2ps::BreakPoint::printPart(xml2ps::Canvas& canvas,
 
 xml2ps::LeaderNode::LeaderNode(Element& parent, const Attributes& attr)
   : Element(parent, "leader", attr), 
-    // Todo: Get column width for percentages
+    /// \todo Get column width for percentages
     width_(attr.get("width", 100 /*%*/, getFont().getSize()))
 {}
 
@@ -277,7 +290,7 @@ xml2ps::LeaderNode::printPart(xml2ps::Canvas& canvas,
 
 xml2ps::ObstacleNode::ObstacleNode(Element& parent, const Attributes& attr)
   : Element(parent, "obstacle", attr),
-    // Todo: Get column width for percentages
+    /// \todo Get column width for percentages
     left_(attr.get("left", 0, getFont().getSize())),
     right_(attr.get("right", 0, getFont().getSize())),
     top_(attr.get("top", 0, getFont().getSize())),
@@ -294,7 +307,7 @@ xml2ps::ObstacleNode::printPart(Canvas& canvas,
   return this;
 }
 
-// - - - BreakPoint - - -
+// - - - LineBreak - - -
 
 // noop
 const xml2ps::Node*
@@ -306,6 +319,41 @@ xml2ps::LineBreak::printPart(xml2ps::Canvas& canvas,
   return this;
 }
 
+// - - - PageNum - - -
+
+xml2ps::PageNum::PageNum(Element& parent, const Attributes& attr)
+  : Element(parent, "pagenum", parent.getFont())
+{
+  type = ARABIC;
+  if(attr.get("type") == "roman-lower")
+    type = ROMAN_LOWER;
+  else if(attr.get("type") == "roman-upper")
+    type = ROMAN_UPPER;
+}
+
+float
+xml2ps::PageNum::getWidth() const {
+  TextNode textnode(getParent(), getStr(1976));
+  return textnode.getWidth();
+}
+
+const xml2ps::Node*
+xml2ps::PageNum::printPart(xml2ps::Canvas& canvas, 
+			   const xml2ps::Node*, const xml2ps::Node*,
+			   const float&, const float&) const {
+  canvas.show(getStr(canvas.getCurrentPage().num()));
+  return this;
+}
+
+std::string 
+xml2ps::PageNum::getStr(int num) const {
+  switch(type) {
+  case ROMAN_LOWER: return to_roman(num); break;
+  case ROMAN_UPPER: return Glib::ustring(to_roman(num)).uppercase(); break;
+  default: return tostr(num);
+  }
+}
+
 // - - TextContainer - -
 
 void xml2ps::TextContainer::add(Node* node) {
@@ -320,7 +368,7 @@ void xml2ps::TextContainer::close() {
 namespace {
 
   bool hasWhite(Glib::ustring s) {
-    // TODO: unicode whitespace
+    /// \todo unicode whitespace
     return s.length() > 0 && whitespace(s[0]);
   }
 
